import {Component} from '@angular/core'
import {CompanyService} from '../../service/company.service'
import {Validators} from '@angular/forms'
import {ErrorHandlingComponent} from '../../../shared/components/subscribing.component'
import {FormField} from '../../../shared/components/entity-add/entity-add.component'
import {ActivatedRoute, Router} from '@angular/router'
import {ErrorModel, ErrorService} from '../../../shared/service/error.service'

@Component({
  selector: 'cre-add',
  templateUrl: './add.component.html',
  styleUrls: ['./add.component.sass']
})
export class AddComponent extends ErrorHandlingComponent {
  formFields: FormField[] = [
    {
      name: 'name',
      label: 'Nom',
      icon: 'form-textbox',
      type: 'text',
      validator: Validators.required,
      errorMessages: [
        {conditionFn: errors => errors.required, message: 'Un nom est requis'}
      ]
    }
  ]
  submittedValues: any | null

  handledErrorModels: ErrorModel[] = [{
    filter: error => error.status === 409,
    messageProducer: () => `Une bannière avec le nom '${this.submittedValues.name}' existe déjà`
  }]

  constructor(
    private companyService: CompanyService,
    errorService: ErrorService,
    router: Router,
    activatedRoute: ActivatedRoute
  ) {
    super(errorService, activatedRoute, router)
  }

  ngOnInit() {
    super.ngOnInit()
  }

  submit(values) {
    this.submittedValues = values
    this.subscribeAndNavigate(
      this.companyService.save(values.name),
      '/catalog/company/list'
    )
  }
}
