import {Component} from '@angular/core'
import {ErrorHandlingComponent} from '../../../shared/components/subscribing.component'
import {Company} from '../../../shared/model/company.model'
import {FormField} from '../../../shared/components/entity-add/entity-add.component'
import {Validators} from '@angular/forms'
import {CompanyService} from '../../service/company.service'
import {ActivatedRoute, Router} from '@angular/router'
import {ErrorModel, ErrorService} from '../../../shared/service/error.service'

@Component({
  selector: 'cre-edit',
  templateUrl: './edit.component.html',
  styleUrls: ['./edit.component.sass']
})
export class EditComponent extends ErrorHandlingComponent {
  company: Company | null
  formFields: FormField[] = [
    {
      name: 'name',
      label: 'Nom',
      icon: 'form-textbox',
      type: 'text',
      validator: Validators.required,
      errorMessages: [
        {conditionFn: errors => errors.required, message: 'Un nom est requis'}
      ]
    }
  ]

  handledErrorModels: ErrorModel[] = [{
    filter: error => error.status === 409,
    messageProducer: error => `Une bannière avec le nom '${error.error.id}' existe déjà`
  }]

  constructor(
    private companyService: CompanyService,
    errorService: ErrorService,
    router: Router,
    activatedRoute: ActivatedRoute
  ) {
    super(errorService, activatedRoute, router)
  }

  ngOnInit(): void {
    super.ngOnInit()

    const id = parseInt(this.activatedRoute.snapshot.paramMap.get('id'))
    this.subscribeEntityById(
      this.companyService,
      id,
      company => this.company = company,
      '/catalog/company/list'
    )
  }

  submit(values) {
    this.subscribeAndNavigate(
      this.companyService.update(this.company.id, values.name),
      '/catalog/company/list'
    )
  }

  delete() {
    this.subscribeAndNavigate(
      this.companyService.delete(this.company.id),
      '/catalog/company/list'
    )
  }
}
